@@ -4,13 +4,9 @@ module Net
   module SSH 
     module Transport 
       module Kex
-
         # A key-exchange service implementing the "diffie-hellman-group14-sha1"
         # key-exchange algorithm. (defined in RFC 4253)
         class DiffieHellmanGroup14SHA1 < DiffieHellmanGroup1SHA1
-          include Loggable
-          include Constants
-      
           # The value of 'P', as a string, in hexadecimal
           P_s = "FFFFFFFF" "FFFFFFFF" "C90FDAA2" "2168C234" +
                 "C4C6628B" "80DC1CD1" "29024E08" "8A67CC74" +
@@ -31,19 +27,9 @@ module Net
       
           # The radix in which P_s represents the value of P
           P_r = 16
-      
+
           # The group constant
           G = 2
-      
-          private
-      
-          def get_p
-            OpenSSL::BN.new(P_s, P_r)
-          end
-      
-          def get_g
-            G
-          end
         end
       end
     end
