@@ -2,56 +2,57 @@ require 'common'
 require 'net/ssh/authentication/methods/hostbased'
 require 'authentication/methods/common'
 
-module Authentication; module Methods
+module Authentication
+  module Methods
 
-  class TestHostbased < NetSSHTest
-    include Common
+    class TestHostbased < NetSSHTest
+      include Common
 
-    def test_authenticate_should_return_false_when_no_key_manager_has_been_set
-      assert_equal false, subject(key_manager: nil).authenticate("ssh-connection", "jamis")
-    end
+      def test_authenticate_should_return_false_when_no_key_manager_has_been_set
+        assert_equal false, subject(key_manager: nil).authenticate("ssh-connection", "jamis")
+      end
 
-    def test_authenticate_should_return_false_when_key_manager_has_no_keys
-      assert_equal false, subject(keys: []).authenticate("ssh-connection", "jamis")
-    end
+      def test_authenticate_should_return_false_when_key_manager_has_no_keys
+        assert_equal false, subject(keys: []).authenticate("ssh-connection", "jamis")
+      end
 
-    def test_authenticate_should_return_false_if_no_keys_can_authenticate
-      ENV.stubs(:[]).with('USER').returns(nil)
-      key_manager.expects(:sign).with(&signature_parameters(keys.first)).returns("sig-one")
-      key_manager.expects(:sign).with(&signature_parameters(keys.last)).returns("sig-two")
+      def test_authenticate_should_return_false_if_no_keys_can_authenticate
+        ENV.stubs(:[]).with('USER').returns(nil)
+        key_manager.expects(:sign).with(&signature_parameters(keys.first)).returns("sig-one")
+        key_manager.expects(:sign).with(&signature_parameters(keys.last)).returns("sig-two")
 
-      transport.expect do |t, packet|
-        assert_equal USERAUTH_REQUEST, packet.type
-        assert verify_userauth_request_packet(packet, keys.first)
-        assert_equal "sig-one", packet.read_string
-        t.return(USERAUTH_FAILURE, :string, "hostbased,password")
+        transport.expect do |t, packet|
+          assert_equal USERAUTH_REQUEST, packet.type
+          assert verify_userauth_request_packet(packet, keys.first)
+          assert_equal "sig-one", packet.read_string
+          t.return(USERAUTH_FAILURE, :string, "hostbased,password")
 
-        t.expect do |t2, packet2|
-          assert_equal USERAUTH_REQUEST, packet2.type
-          assert verify_userauth_request_packet(packet2, keys.last)
-          assert_equal "sig-two", packet2.read_string
-          t2.return(USERAUTH_FAILURE, :string, "hostbased,password")
+          t.expect do |t2, packet2|
+            assert_equal USERAUTH_REQUEST, packet2.type
+            assert verify_userauth_request_packet(packet2, keys.last)
+            assert_equal "sig-two", packet2.read_string
+            t2.return(USERAUTH_FAILURE, :string, "hostbased,password")
+          end
         end
+
+        assert_equal false, subject.authenticate("ssh-connection", "jamis")
       end
 
-      assert_equal false, subject.authenticate("ssh-connection", "jamis")
-    end
+      def test_authenticate_should_return_true_if_any_key_can_authenticate
+        ENV.stubs(:[]).with('USER').returns(nil)
+        key_manager.expects(:sign).with(&signature_parameters(keys.first)).returns("sig-one")
 
-    def test_authenticate_should_return_true_if_any_key_can_authenticate
-      ENV.stubs(:[]).with('USER').returns(nil)
-      key_manager.expects(:sign).with(&signature_parameters(keys.first)).returns("sig-one")
+        transport.expect do |t, packet|
+          assert_equal USERAUTH_REQUEST, packet.type
+          assert verify_userauth_request_packet(packet, keys.first)
+          assert_equal "sig-one", packet.read_string
+          t.return(USERAUTH_SUCCESS)
+        end
 
-      transport.expect do |t, packet|
-        assert_equal USERAUTH_REQUEST, packet.type
-        assert verify_userauth_request_packet(packet, keys.first)
-        assert_equal "sig-one", packet.read_string
-        t.return(USERAUTH_SUCCESS)
+        assert subject.authenticate("ssh-connection", "jamis")
       end
 
-      assert subject.authenticate("ssh-connection", "jamis")
-    end
-
-    private
+      private
 
       def signature_parameters(key)
         Proc.new do |given_key, data|
@@ -69,8 +70,8 @@ module Authentication; module Methods
         packet.read_string == "hostbased"      && # auth-method
         packet.read_string == key.ssh_type     && # key type
         packet.read_buffer.read_key.to_blob == key.to_blob && # key
-        packet.read_string == "me.ssh.test."   && # client hostname
-        packet.read_string == "jamis"             # client username
+        packet.read_string == "me.ssh.test." && # client hostname
+        packet.read_string == "jamis" # client username
       end
 
       @@keys = nil
@@ -108,7 +109,6 @@ module Authentication; module Methods
           sess
         end
       end
-
+    end
   end
-
-end; end
+end
