@@ -24,18 +24,6 @@ require 'tempfile'
 class ForwardTestBase < NetSSHTest
   include IntegrationTestHelpers
 
-  # @yield [pid, port]
-  def start_sshd_7_or_later(port = '2200')
-    pid = spawn('sudo', '/opt/net-ssh-openssh/sbin/sshd', '-D', '-p', port)
-    yield pid, port
-  ensure
-    # Our pid is sudo, -9 (KILL) on sudo will not clean up its children
-    # properly, so we just have to hope that -15 (TERM) will manage to bring
-    # down sshd.
-    system('sudo', 'kill', '-15', pid.to_s)
-    Process.wait(pid)
-  end
-
   def localhost
     'localhost'
   end
@@ -209,7 +197,7 @@ class TestForward < ForwardTestBase
         end
       end
       session.loop(0.1) { client_done.empty? }
-      assert_equal "Broken pipe", "#{server_exc.pop}" unless server_exc.empty?
+      assert_equal "Broken pipe", server_exc.pop.to_s unless server_exc.empty?
     end
   end
 
@@ -234,7 +222,7 @@ class TestForward < ForwardTestBase
         end
       end
       session.loop(0.1) { client_done.empty? }
-      assert_equal "Broken pipe", "#{server_exc.pop}" unless server_exc.empty?
+      assert_equal "Broken pipe", server_exc.pop.to_s unless server_exc.empty?
     end
   end
 
@@ -326,9 +314,7 @@ class TestForward < ForwardTestBase
     end
 
     def close_all
-      sockets.each do |socket|
-        socket.close
-      end
+      sockets.each(&:close)
     end
   end
 
@@ -339,7 +325,7 @@ class TestForward < ForwardTestBase
         sleep(100)
         client.puts "Hallo"
       end
-      proxy = TCPProxy.new()
+      proxy = TCPProxy.new
       session = Net::SSH.start(*ssh_start_params(proxy: proxy))
       remote_port = server.addr[1]
       local_port = session.forward.local(0, localhost, remote_port)
@@ -364,7 +350,7 @@ class TestForward < ForwardTestBase
           session.loop(0.1) { true }
         rescue IOError, Errno::EBADF
           server_error = $!
-          #puts "Error: #{$!} #{$!.backtrace.join("\n")}"
+          # puts "Error: #{$!} #{$!.backtrace.join("\n")}"
         end
       end
       begin
@@ -412,7 +398,7 @@ class TestForward < ForwardTestBase
             session.close
           rescue StandardError
           end
-          #puts "Error: #{$!} #{$!.backtrace.join("\n")}"
+          # puts "Error: #{$!} #{$!.backtrace.join("\n")}"
         end
         assert_equal true, client_done.pop
       end
