@@ -44,11 +44,11 @@ class TestConfig < NetSSHTest
   end
 
   def test_load_with_pattern_does_match
-    data = %q{
+    data = '
       Host test.*
         Port 1234
         Compression no
-    }
+    '
     with_config_from_data data do |f|
       config = Net::SSH::Config.load(f, "test.host")
       assert_equal 1234, config['port']
@@ -56,10 +56,10 @@ class TestConfig < NetSSHTest
   end
 
   def test_check_host_ip
-    data = %q{
+    data = '
       Host *
         CheckHostIP no
-    }
+    '
     with_config_from_data data do |f|
       config = Net::SSH::Config.load(f, 'foo')
       assert_equal false, config['checkhostip']
@@ -70,11 +70,11 @@ class TestConfig < NetSSHTest
   end
 
   def test_load_with_regex_chars
-    data = %q{
+    data = '
       Host |
         Port 1234
         Compression no
-    }
+    '
     with_config_from_data data do |f|
       config = Net::SSH::Config.load(f, "test.host")
       assert_nil config['port']
@@ -89,6 +89,7 @@ class TestConfig < NetSSHTest
     assert config[:compression]
     assert config[:forward_agent]
     assert_equal %w(~/.ssh/id_dsa), config[:keys]
+    assert_equal %w(~/.ssh/id_rsa-my-cert.pub ~/.ssh/cert.pub), config[:keycerts]
     assert !config.key?(:rekey_limit)
   end
 
@@ -131,15 +132,19 @@ class TestConfig < NetSSHTest
       'hostkeyalgorithms'       => "d,e,f",
       'identityfile'            => %w(g h i),
       'macs'                    => "j,k,l",
+      'certificatefile'         => %w(m n o),
       'passwordauthentication'  => true,
       'port'                    => 1234,
       'pubkeyauthentication'    => true,
       'rekeylimit'              => 1024,
       'sendenv'                 => "LC_*",
+      'setenv'                  => 'foo="bar" baz=whale cat="black hole"',
       'numberofpasswordprompts' => '123',
       'serveraliveinterval'     => '2',
       'serveralivecountmax'     => '4',
-      'fingerprinthash'         => 'MD5'
+      'fingerprinthash'         => 'MD5',
+      'userknownhostsfile'      => '/dev/null',
+      'stricthostkeychecking'   => false
     }
 
     net_ssh = Net::SSH::Config.translate(open_ssh)
@@ -153,15 +158,19 @@ class TestConfig < NetSSHTest
     assert_equal %w(d e f), net_ssh[:host_key]
     assert_equal %w(g h i), net_ssh[:keys]
     assert_equal %w(j k l), net_ssh[:hmac]
+    assert_equal %w(m n o), net_ssh[:keycerts]
     assert_equal 1234,      net_ssh[:port]
     assert_equal 1024,      net_ssh[:rekey_limit]
     assert_equal "127.0.0.1", net_ssh[:bind_address]
     assert_equal [/^LC_.*$/], net_ssh[:send_env]
+    assert_equal Hash['foo' => 'bar', 'baz' => 'whale', 'cat' => 'black hole'], net_ssh[:set_env]
     assert_equal 123,       net_ssh[:number_of_password_prompts]
     assert_equal 4,         net_ssh[:keepalive_maxcount]
     assert_equal 2,         net_ssh[:keepalive_interval]
     assert_equal 'MD5',     net_ssh[:fingerprint_hash]
-    assert_equal true, net_ssh[:keepalive]
+    assert_equal true,      net_ssh[:keepalive]
+    assert_equal '/dev/null', net_ssh[:user_known_hosts_file]
+    assert_equal false, net_ssh[:strict_host_key_checking]
   end
 
   def test_translate_should_turn_off_authentication_methods
@@ -278,6 +287,12 @@ class TestConfig < NetSSHTest
     assert_equal [/^GIT_.*$/, /^LANG$/, /^LC_.*$/], net_ssh[:send_env]
   end
 
+  def test_load_with_set_env
+    config = Net::SSH::Config.load(config(:set_env), '1234')
+    net_ssh = Net::SSH::Config.translate(config)
+    assert_equal Hash['foo' => 'bar', 'baz' => 'whale', 'cat' => 'black hole'], net_ssh[:set_env]
+  end
+
   def test_load_with_remote_user
     config = Net::SSH::Config.load(config(:proxy_remote_user), "behind-proxy")
     net_ssh = Net::SSH::Config.translate(config)
@@ -328,11 +343,11 @@ class TestConfig < NetSSHTest
   end
 
   def test_load_with_match_block_with_host
-    data = %q{
+    data = '
       Match Host foo
         Port 1234
         Compression no
-    }
+    '
     with_config_from_data data do |f|
       config = Net::SSH::Config.load(f, "bar")
       assert_nil config['port']
@@ -342,11 +357,11 @@ class TestConfig < NetSSHTest
   end
 
   def test_load_with_match_block_with_hosts
-    data = %q{
+    data = '
       Match Host foo,bar
         Port 1234
         Compression no
-    }
+    '
     with_config_from_data data do |f|
       config = Net::SSH::Config.load(f, "bar2")
       assert_nil config['port']
@@ -358,11 +373,11 @@ class TestConfig < NetSSHTest
   end
 
   def test_load_with_match_block_with_hosts_wildcard
-    data = %q{
+    data = '
       Match Host foo,*.baz.com
         Port 1234
         Compression no
-    }
+    '
     with_config_from_data data do |f|
       config = Net::SSH::Config.load(f, "bar2")
       assert_nil config['port']
@@ -377,11 +392,11 @@ class TestConfig < NetSSHTest
 
   def test_load_with_match_block_with_multi_space_separated_hosts_condition
     # Extra tabs are thrown in between, for good measure
-    data = %q{
+    data = '
       Match host 		 foo,*.baz.com
         Port 1234
         Compression no
-    }
+    '
     with_config_from_data data do |f|
       config = Net::SSH::Config.load(f, "bar2")
       assert_nil config['port']
@@ -395,11 +410,11 @@ class TestConfig < NetSSHTest
   end
 
   def test_load_with_match_block_with_quoted_hosts_condition
-    data = %q{
+    data = '
       Match host "foo,*.baz.com"
         Port 1234
         Compression no
-    }
+    '
     with_config_from_data data do |f|
       config = Net::SSH::Config.load(f, "bar2")
       assert_nil config['port']
@@ -413,11 +428,11 @@ class TestConfig < NetSSHTest
   end
 
   def test_load_with_match_block_with_equal_signed_hosts_condition
-    data = %q{
+    data = '
       Match host=foo,*.baz.com
         Port 1234
         Compression no
-    }
+    '
     with_config_from_data data do |f|
       config = Net::SSH::Config.load(f, "bar2")
       assert_nil config['port']
@@ -431,11 +446,11 @@ class TestConfig < NetSSHTest
   end
 
   def test_load_with_match_block_with_quoted_equal_signed_hosts_condition
-    data = %q{
+    data = '
       Match host="foo,*.baz.com"
         Port 1234
         Compression no
-    }
+    '
     with_config_from_data data do |f|
       config = Net::SSH::Config.load(f, "bar2")
       assert_nil config['port']
@@ -449,11 +464,11 @@ class TestConfig < NetSSHTest
   end
 
   def test_load_with_match_block_with_whitespace_separated_equal_signed_hosts_condition
-    data = %q{
+    data = '
       Match host = foo,*.baz.com
         Port 1234
         Compression no
-    }
+    '
     with_config_from_data data do |f|
       config = Net::SSH::Config.load(f, "bar2")
       assert_nil config['port']
@@ -467,11 +482,11 @@ class TestConfig < NetSSHTest
   end
 
   def test_load_with_match_block_with_multi_equal_signed_hosts_condition
-    data = %q{
+    data = '
       Match host==foo,*.baz.com
         Port 1234
         Compression no
-    }
+    '
     with_config_from_data data do |f|
       config = Net::SSH::Config.load(f, "bar2")
       assert_nil config['port']
@@ -485,10 +500,10 @@ class TestConfig < NetSSHTest
   end
 
   def test_load_with_multiple_hosts_criteria
-    data = %q{
+    data = '
       Match host *.baz.com host !bar.baz.com
         Port 1234
-    }
+    '
     with_config_from_data data do |f|
       config = Net::SSH::Config.load(f, "bar2")
       assert_nil config['port']
@@ -501,6 +516,17 @@ class TestConfig < NetSSHTest
     end
   end
 
+  def test_mix_of_proxy_command_and_proxy_jump
+    %w(test.mix1 test.mix2).each do |host|
+      config = Net::SSH::Config.for(host, [config(:proxy_command_proxy_jump_mix)])
+
+      proxy = config[:proxy]
+      proxy.build_proxy_command_equivalent if proxy.is_a? Net::SSH::Proxy::Jump
+
+      assert_equal 'ssh -W %h:%p jump2', config[:proxy].command_line_template
+    end
+  end
+
   private
 
   def with_home_env(value,&block)
